==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-aws/camel-aws2-ddb/src/main/java/org/apache/camel/component/aws2/ddbstream/Ddb2StreamConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.ddbstream;

import org.apache.camel.spi.Metadata;

/**
 * Constants used in Camel AWS DynamoDB Streams component
 */
public interface Ddb2StreamConstants {
    @Metadata(label = "consumer",
              description = "The Amazon Web Services service from which the stream record originated. For DynamoDB Streams, this is aws:dynamodb.",
              javaType = "String")
    String EVENT_SOURCE = "CamelAwsDdbStreamEventSource";
    @Metadata(label = "consumer",
              description = "A globally unique identifier for the event that was recorded in this stream record.",
              javaType = "String")
    String EVENT_ID = "CamelAwsDdbStreamEventId";
}

==> apache-camel-4.18.0-src.zip: apache-camel-4.18.0/components/camel-aws/camel-aws2-ddb/src/main/java/org/apache/camel/component/aws2/ddbstream/Ddb2StreamConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.ddbstream;

import org.apache.camel.spi.Metadata;

/**
 * Constants used in Camel AWS DynamoDB Streams component
 */
public interface Ddb2StreamConstants {
    @Metadata(label = "consumer",
              description = "The Amazon Web Services service from which the stream record originated. For DynamoDB Streams, this is aws:dynamodb.",
              javaType = "String")
    String EVENT_SOURCE = "CamelAwsDdbStreamEventSource";
    @Metadata(label = "consumer",
              description = "A globally unique identifier for the event that was recorded in this stream record.",
              javaType = "String")
    String EVENT_ID = "CamelAwsDdbStreamEventId";
    @Metadata(label = "consumer",
              description = "The type of data modification that was performed on the DynamoDB table (INSERT, MODIFY, REMOVE).",
              javaType = "String")
    String EVENT_NAME = "CamelAwsDdbStreamEventName";
    @Metadata(label = "consumer",
              description = "The sequence number of the stream record.",
              javaType = "String")
    String SEQUENCE_NUMBER = "CamelAwsDdbStreamSequenceNumber";
    @Metadata(label = "consumer",
              description = "The approximate date and time when the stream record was created.",
              javaType = "java.time.Instant")
    String APPROXIMATE_CREATION_DATE_TIME = "CamelAwsDdbStreamApproximateCreationDateTime";
    @Metadata(label = "consumer",
              description = "The size of the stream record, in bytes.",
              javaType = "Long")
    String SIZE_BYTES = "CamelAwsDdbStreamSizeBytes";
}
